#include "window.h"
#include "ui_window.h"

#include "shape.h"
#include "colorbutton.h"
#include "shapebutton.h"

#include <QApplication>

#include <QDrag>
#include <QMimeData>
#include <QIcon>
#include <QGraphicsSceneDragDropEvent>
#include <QGraphicsRectItem>

#include <cassert>

/* static */

MainWindow * MainWindow::instance = NULL;

/* properties */

/* scene selection changed */

void MainWindow::scene_selection_changed()
{
    QList <QGraphicsItem *> sel = scene->selectedItems ();
    if (sel.count() == 1)
    {
        QGraphicsItem * item = sel [0];
        current_item = item;
    }
}

/* MainWindow */

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow (parent),
    ui(new Ui::MainWindow),
    scene (NULL),
    current_item (NULL)
{
    ui->setupUi(this);

    /* setup tools */

    ui->mainToolBar->addWidget (new ShapeButton ("ellipse"));
    ui->mainToolBar->addWidget (new ShapeButton ("rectangle"));

    ui->mainToolBar->addSeparator ();

    /* setup colors */

    QList <QString> names;
    names << "red" << "blue" << "green" << "yellow" << "orange";

    for (auto name : names)
    {
       ColorButton * b = new ColorButton (name);
       ui->mainToolBar->addWidget (b);
    }

    /* setup scene */

    scene = new QGraphicsScene;
    ui->graphicsView->setScene (scene);

    QObject::connect (scene, SIGNAL (selectionChanged()),
                      this, SLOT (scene_selection_changed()));

    scene->setSceneRect (0, 0, 1280, 1024);

    Plane * p = new Plane;
    scene->addItem (p);

    Rectangle * r = new Rectangle;
    r->setParentItem (p);

    Ellipse * e = new Ellipse;
    e->setParentItem (p);

    /* setup window */

     ui->input->setVisible (false);

     ui->hsplitter->setStretchFactor (0, 1);
     ui->hsplitter->setStretchFactor (1, 4);
     ui->hsplitter->setStretchFactor (2, 1);

     ui->vsplitter->setStretchFactor (0, 4);
     ui->vsplitter->setStretchFactor (1, 1);
     ui->vsplitter->setStretchFactor (2, 1);
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::on_actionQuit_triggered()
{
   this->close ();
}

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    MainWindow w;
    w.show();
    return a.exec();
}

